@@ -203,12 +203,12 @@ impl Paragraph {
         self
     }
 
-    pub(crate) fn hanging_chars(mut self, chars: i32) -> Paragraph {
+    pub fn hanging_chars(mut self, chars: i32) -> Paragraph {
         self.property = self.property.hanging_chars(chars);
         self
     }
 
-    pub(crate) fn first_line_chars(mut self, chars: i32) -> Paragraph {
+    pub fn first_line_chars(mut self, chars: i32) -> Paragraph {
         self.property = self.property.first_line_chars(chars);
         self
     }
@@ -239,21 +239,13 @@ impl Paragraph {
         self
     }
 
-    pub(crate) fn run_property(mut self, p: RunProperty) -> Self {
+    pub fn run_property(mut self, p: RunProperty) -> Self {
         self.property.run_property = p;
         self
     }
 
-    pub fn line_spacing(
-        mut self,
-        before: Option<u32>,
-        after: Option<u32>,
-        line: Option<u32>,
-        spacing_type: Option<LineSpacingType>,
-    ) -> Self {
-        self.property = self
-            .property
-            .line_spacing(before, after, line, spacing_type);
+    pub fn line_spacing(mut self, spacing: LineSpacing) -> Self {
+        self.property = self.property.line_spacing(spacing);
         self
     }
 }
@@ -334,8 +326,13 @@ mod tests {
 
     #[test]
     fn test_line_spacing_and_character_spacing() {
+        let spacing = LineSpacing::new()
+            .line_rule(LineSpacingType::Auto)
+            .before(20)
+            .after(30)
+            .line(200);
         let b = Paragraph::new()
-            .line_spacing(Some(20), Some(30), Some(200), Some(LineSpacingType::Auto))
+            .line_spacing(spacing)
             .add_run(Run::new().add_text("Hello"))
             .build();
         assert_eq!(
