@@ -17,7 +17,7 @@ pub struct XMLDocx {
     pub font_table: Vec<u8>,
     pub numberings: Vec<u8>,
     pub media: Vec<(usize, Vec<u8>)>,
-    pub header: Vec<u8>,
+    pub header: Option<Vec<u8>>,
     pub footer: Option<Vec<u8>>,
     pub comments_extended: Vec<u8>,
     pub taskpanes: Option<Vec<u8>>,
